==> dojo_1.11.0+dfsg.orig.tar.gz: dojo-release-1.11.0-src/dojo/cldr/nls/he/generic.js <==
define(
//begin v1.x content
{
	"field-second-relative+0": "עכשיו",
	"field-weekday": "יום בשבוע",
	"field-wed-relative+0": "יום רביעי",
	"field-wed-relative+1": "יום רביעי הבא",
	"dateFormatItem-GyMMMEd": "E, d בMMM y G",
	"dateFormatItem-MMMEd": "E, d בMMM",
	"field-tue-relative+-1": "יום שלישי שעבר",
	"dateFormat-long": "d בMMMM y G",
	"field-fri-relative+-1": "יום שישי שעבר",
	"field-wed-relative+-1": "יום רביעי שעבר",
	"dateFormatItem-yyyyQQQ": "G y QQQ",
	"dateTimeFormat-medium": "{1}, {0}",
	"dateFormat-full": "EEEE, d בMMMM y G",
	"dateFormatItem-yyyyMEd": "E, d/M/y G",
	"field-thu-relative+-1": "יום חמישי שעבר",
	"dateFormatItem-Md": "d/M",
	"field-era": "תקופה",
	"field-year": "שנה",
	"field-hour": "שעה",
	"field-sat-relative+0": "השבת הזאת",
	"field-sat-relative+1": "השבת הבאה",
	"field-day-relative+0": "היום",
	"field-day-relative+1": "מחר",
	"field-thu-relative+0": "יום חמישי",
	"dateFormatItem-GyMMMd": "d בMMM y G",
	"field-day-relative+2": "מחרתיים",
	"field-thu-relative+1": "יום חמישי הבא",
	"dateFormatItem-H": "HH",
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E, d בMMM y G",
	"dateFormatItem-M": "L",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"dateFormatItem-yyyyMMMd": "d בMMM y G",
	"field-sun-relative+0": "יום ראשון",
	"dateFormatItem-Hm": "HH:mm",
	"field-sun-relative+1": "יום ראשון הבא",
	"field-minute": "דקה",
	"field-dayperiod": "לפנה״צ/אחה״צ",
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+-1": "אתמול",
	"dateFormatItem-h": "‏h a",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "שלשום",
	"dateFormatItem-MMMd": "d בMMM",
	"dateFormatItem-MEd": "E, d/M",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "יום שישי",
	"field-fri-relative+1": "יום שישי הבא",
	"field-day": "יום",
	"field-zone": "אזור",
	"dateFormatItem-yyyyMM": "MM/y G",
	"dateFormatItem-y": "y G",
	"field-year-relative+-1": "השנה שעברה",
	"field-month-relative+-1": "החודש שעבר",
	"dateFormatItem-hm": "h:mm a",
	"dateFormatItem-yyyyMd": "d.M.y G",
	"field-month": "חודש",
	"dateFormatItem-MMM": "LLL",
	"field-tue-relative+0": "יום שלישי",
	"field-tue-relative+1": "יום שלישי הבא",
	"field-mon-relative+0": "יום שני הזה",
	"field-mon-relative+1": "יום שני הבא",
	"dateFormat-short": "dd/MM/yy GGGGG",
	"field-second": "שנייה",
	"field-sat-relative+-1": "השבת שעברה",
	"field-sun-relative+-1": "יום ראשון שעבר",
	"field-month-relative+0": "החודש",
	"field-month-relative+1": "החודש הבא",
	"dateFormatItem-Ed": "E ה-d",
	"field-week": "שבוע",
	"dateFormat-medium": "d בMMM y G",
	"field-year-relative+0": "השנה",
	"field-week-relative+-1": "השבוע שעבר",
	"dateFormatItem-yyyyM": "M.y G",
	"field-year-relative+1": "השנה הבאה",
	"dateFormatItem-yyyyQQQQ": "G y QQQQ",
	"dateTimeFormat-short": "{1}, {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "יום שני שעבר",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "השבוע",
	"field-week-relative+1": "השבוע הבא"
}
//end v1.x content
);

==> dojo_1.14.2+dfsg1.orig.tar.gz: dojo-release-1.14.2-src/dojo/cldr/nls/he/generic.js <==
define(
//begin v1.x content
{
	"field-second-relative+0": "עכשיו",
	"field-weekday": "יום בשבוע",
	"field-wed-relative+0": "יום רביעי",
	"field-wed-relative+1": "יום רביעי הבא",
	"dateFormatItem-GyMMMEd": "E, d בMMM y G",
	"dateFormatItem-MMMEd": "E, d בMMM",
	"field-tue-relative+-1": "יום שלישי שעבר",
	"dateFormat-long": "d בMMMM y G",
	"field-fri-relative+-1": "יום שישי שעבר",
	"field-wed-relative+-1": "יום רביעי שעבר",
	"dateFormatItem-yyyyQQQ": "G y QQQ",
	"dateTimeFormat-medium": "{1}, {0}",
	"dateFormat-full": "EEEE, d בMMMM y G",
	"dateFormatItem-yyyyMEd": "E, d/M/y G",
	"field-thu-relative+-1": "יום חמישי שעבר",
	"dateFormatItem-Md": "d.M",
	"field-era": "תקופה",
	"field-year": "שנה",
	"field-hour": "שעה",
	"field-sat-relative+0": "יום שבת",
	"field-sat-relative+1": "יום שבת הבא",
	"field-day-relative+0": "היום",
	"field-day-relative+1": "מחר",
	"field-thu-relative+0": "יום חמישי",
	"dateFormatItem-GyMMMd": "d בMMM y G",
	"field-day-relative+2": "מחרתיים",
	"field-thu-relative+1": "יום חמישי הבא",
	"dateFormatItem-H": "H",
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E, d בMMM y G",
	"dateFormatItem-M": "L",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"dateFormatItem-yyyyMMMd": "d בMMM y G",
	"field-sun-relative+0": "יום ראשון",
	"dateFormatItem-Hm": "H:mm",
	"field-sun-relative+1": "יום ראשון הבא",
	"field-minute": "דקה",
	"field-dayperiod": "לפנה״צ/אחה״צ",
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+-1": "אתמול",
	"dateFormatItem-h": "‏h a",
	"dateTimeFormat-long": "{1} בשעה {0}",
	"field-day-relative+-2": "שלשום",
	"dateFormatItem-MMMd": "d בMMM",
	"dateFormatItem-MEd": "E, d/M",
	"dateTimeFormat-full": "{1} בשעה {0}",
	"field-fri-relative+0": "יום שישי",
	"field-fri-relative+1": "יום שישי הבא",
	"field-day": "יום",
	"field-zone": "אזור",
	"dateFormatItem-yyyyMM": "MM/y G",
	"dateFormatItem-y": "y G",
	"field-year-relative+-1": "השנה שעברה",
	"field-month-relative+-1": "החודש שעבר",
	"dateFormatItem-hm": "h:mm a",
	"dateFormatItem-yyyyMd": "d.M.y G",
	"field-month": "חודש",
	"dateFormatItem-MMM": "LLL",
	"field-tue-relative+0": "יום שלישי",
	"field-tue-relative+1": "יום שלישי הבא",
	"field-mon-relative+0": "יום שני",
	"field-mon-relative+1": "יום שני הבא",
	"dateFormat-short": "d.M.y GGGGG",
	"field-second": "שנייה",
	"field-sat-relative+-1": "יום שבת שעבר",
	"field-sun-relative+-1": "יום ראשון שעבר",
	"field-month-relative+0": "החודש",
	"field-month-relative+1": "החודש הבא",
	"dateFormatItem-Ed": "E ה-d",
	"field-week": "שבוע",
	"dateFormat-medium": "d בMMM y G",
	"field-year-relative+0": "השנה",
	"field-week-relative+-1": "השבוע שעבר",
	"dateFormatItem-yyyyM": "M.y G",
	"field-year-relative+1": "השנה הבאה",
	"dateFormatItem-yyyyQQQQ": "G y QQQQ",
	"dateTimeFormat-short": "{1}, {0}",
	"dateFormatItem-Hms": "H:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "יום שני שעבר",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "השבוע",
	"field-week-relative+1": "השבוע הבא"
}
//end v1.x content
);
